<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class JobControllerTest extends TestCase
{
    use DatabaseTransactions;
    use WithoutMiddleware;

    protected $job;
    protected $company;
    protected $subjob;
    protected $tambon;
    protected $ctr;
    protected $viewerLog;

    protected function setup(){

        parent::setup();

        $this->company = factory(App\Company::class)->create()->fresh();

        $this->subjob = factory(App\SubJobType::class)->create()->fresh();

        $this->tambon = factory(App\Tambon::class)
                 ->create(['T_CODE' => '2'])->fresh();

        $this->job = factory(App\Job::class)
            ->create([
                'CompanyCode' => $this->company->RunningNumber,
                'SubJobType' => $this->subjob->Code,
                'TAMBONCODE' => $this->tambon->T_Code,
                'JobType' => 'aaa',
            ])->fresh();

        $this->resume = factory(App\Resume::class)
                ->create([
                    'TAMBONCODE' => '$tambon->T_CODE',
                    'JobType1' => $this->job->JobType,
                    'JobType2' => 'bbb',
                ])->fresh();

        $this->ctr = factory(App\CTR::class)
            ->create(['JobCode' => $this->job->RunningNumber])->fresh();

        $this->viewerLog = factory(App\ViewerLog::class)
            ->create([
                'JobCode' => $this->job->RunningNumber, 
                'CompanyCode' => $this->company->RunningNumber
            ])->fresh();

    }
        

    public function testShow_Detail_Job()
    {
        $jobs = $this->company
            ->jobs()
            ->online()
            ->get();
        
        $active = 'j'.$this->job->RunningNumber;

        $bindings = [
            ['job' => $this->job],
            ['company' => $this->company], 
            ['active' => $active],
            ['jobs' => $jobs],
        ];

        $this->get('/company/'.$this->company->RunningNumber.'/job/'.$this->job->RunningNumber)
            ->assertViewHasAll($bindings);
    }

    public function testJobsList_Dashboard()
    {  

        $jobs = $this->company
            ->jobs()
            ->online()
            ->paginate(20);

        $expact = ['html' =>  View::make(
            'companyHR.dashboardJobList', 
            [
                'jobs' => $jobs,
                'company' => $this->company->RunningNumber,
            ]
        )->render()];

        $actual = $this->get('/company/'.$this->company->RunningNumber.'/joblist')->seeJsonEquals($expact);
    }

    public function test_chartAmount()
    {   
        $total = [];
        $app = factory(App\ApplicationDataAnalyzer::class)
        ->create([
            'JobCode'    => $this->job->RunningNumber,
            'ResumeCode' => $this->resume->RunningNumber,
        ])->fresh();

        $resumes = $app->with('Resume')
                       ->where('JobCode', $this->job->RunningNumber)
                       ->ofPreviousDay(15)
                       ->get();

        foreach($resumes as $resume)
        {
            if($resume->Resume->JobType1==$this->job->JobType || $resume->Resume->JobType2==$this->job->JobType){
                if(isset($total[$this->job->JobType.'(JobType Direct)'])){
                    $total[$this->job->JobType.'(JobType Direct)']++;
                }else{
                    $total[$this->job->JobType.'(JobType Direct)']=1;
                }
            }else{
                if(isset($total[$resume->Resume->JobType1])){
                    $total[$resume->Resume->JobType1]++;
                }else{
                    $total[$resume->Resume->JobType1]=1;
                }
            }
        }
        unset($total['']);
        $expect = array('total' => $total);
             
        $this->get('/job/' . $this->job->RunningNumber . '/amountChart')
        ->seeJsonEquals($expect);
    }
}
